@@ -6,8 +6,10 @@ module Servant.API.Header (
     Header, Header',
     ) where
 
-import           Data.Typeable   (Typeable)
-import           GHC.TypeLits    (Symbol)
+import           Data.Typeable
+                 (Typeable)
+import           GHC.TypeLits
+                 (Symbol)
 import           Servant.API.Modifiers
 
 -- | Extract the given header's value as a value of type @a@.
