@@ -3,7 +3,8 @@ module Servant.API.Vault
     Vault
   ) where
 
-import           Data.Vault.Lazy (Vault)
+import           Data.Vault.Lazy
+                 (Vault)
 
 -- $vault
 --
